Flappy-Turtle
=============

A tutorial of writing a Flappy Bird clone in Python with builtin turtle module

To run it 
```sh
python3 flappybird.py
```

You will need to install mplayer if you want to play with sound effect.

All sound files are public domain found in http://www.pdsounds.org/
